==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/swagger/swagger-invocation/invocation-jaxrs/src/test/java/org/apache/servicecomb/swagger/invocation/jaxrs/response/TestJaxrsProducerResponseMapperFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.swagger.invocation.jaxrs.response;

import javax.ws.rs.core.Response;

import org.hamcrest.Matchers;
import org.junit.Assert;
import org.junit.Test;

public class TestJaxrsProducerResponseMapperFactory {
  JaxrsProducerResponseMapperFactory factory = new JaxrsProducerResponseMapperFactory();

  @Test
  public void isMatch_true() {
    Assert.assertTrue(factory.isMatch(null, Response.class));
  }

  @Test
  public void isMatch_false() {
    Assert.assertFalse(factory.isMatch(null, String.class));
  }

  @Test
  public void createResponseMapper() {
    Assert.assertThat(factory.createResponseMapper(null, null, null),
        Matchers.instanceOf(JaxrsProducerResponseMapper.class));
  }
}

==> apache-servicecomb-java-chassis-distribution-2.6.3-src.zip: apache-servicecomb-java-chassis-distribution-2.6.3-src/swagger/swagger-invocation/invocation-jaxrs/src/test/java/org/apache/servicecomb/swagger/invocation/jaxrs/response/TestJaxrsProducerResponseMapperFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.swagger.invocation.jaxrs.response;

import javax.ws.rs.core.Response;

import org.hamcrest.Matchers;
import org.junit.Assert;
import org.junit.Test;

public class TestJaxrsProducerResponseMapperFactory {
  JaxrsProducerResponseMapperFactory factory = new JaxrsProducerResponseMapperFactory();

  @Test
  public void isMatch_true() {
    Assert.assertTrue(factory.isMatch(Response.class));
  }

  @Test
  public void isMatch_false() {
    Assert.assertFalse(factory.isMatch(String.class));
  }

  @Test
  public void createResponseMapper() {
    Assert.assertThat(factory.createResponseMapper(null, null),
        Matchers.instanceOf(JaxrsProducerResponseMapper.class));
  }
}
